summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAbdellatif El Khlifi <abdellatif.elkhlifi@arm.com>2020-10-16 18:34:41 +0100
committerRui Miguel Silva <rui.silva@arm.com>2020-11-24 13:09:30 +0000
commit24475b9417cdee636b9a789db6bacd1ccb278d4d (patch)
tree573d59c1cec4061839ec3d37e8fb9e3838af0018
parent7342c80a5b821bc25d937c3a671c4fca11edc978 (diff)
corstone500: branding CA5DS to Corstone-500
This commit changes the name of CA5DS platform to Corstone-500 Change-Id: I841f2a843bf81cacb3f541b4aeda82cb722febec Signed-off-by: Abdellatif El Khlifi <abdellatif.elkhlifi@arm.com>
-rwxr-xr-xiot/run_model.sh20
-rw-r--r--iot/scripts/platforms/corstone500/corstone500_fvp.py (renamed from iot/scripts/platforms/a5ds/a5ds_fvp.py)19
-rw-r--r--iot/scripts/platforms/corstone500/corstone500_testrunner.py (renamed from iot/scripts/platforms/a5ds/a5ds_testrunner.py)12
3 files changed, 30 insertions, 21 deletions
diff --git a/iot/run_model.sh b/iot/run_model.sh
index 1187a6c..8ec2c3a 100755
--- a/iot/run_model.sh
+++ b/iot/run_model.sh
@@ -27,7 +27,7 @@ then
fi
cs700="Corstone-700"
-a5ds="CA5DS"
+cs500="Corstone-500"
YOCTO_DISTRO="poky-tiny"
YOCTO_IMAGE="arm-reference-image"
@@ -43,8 +43,16 @@ if [[ $1 =~ $cs700 ]]; then
DIRNAME=corstone700
else
- OUTDIR=${BASEDIR}/../../build-${YOCTO_DISTRO}/tmp-${echo ${YOCTO_DISTRO} | sed 's/-/_/g'}/deploy/images/a5ds
- DIRNAME=a5ds
+
+ if [ -z "$MACHINE" ]; then
+ MACHINE="corstone500"
+ fi
+
+ echo "Corstone500: using $MACHINE machine , $YOCTO_DISTRO DISTRO"
+
+ OUTDIR=${BASEDIR}/../../build-${YOCTO_DISTRO}/tmp-$(echo ${YOCTO_DISTRO} | sed 's/-/_/g')/deploy/images/${MACHINE}
+ DIRNAME=corstone500
+
fi
if [ -z "$2" -o "$2" == "-S" ]
@@ -59,11 +67,11 @@ then
-C board.hostbridge.interfaceName="tap0" \
-C board.smsc_91c111.enabled=1 \
$2
- elif [[ $1 =~ $a5ds ]]; then
- echo "================== Launching CA5-DS Model ==============================="
+ elif [[ $1 =~ $cs500 ]]; then
+ echo "================== Launching Corstone-500 Model ==============================="
$1 \
-C board.flashloader0.fname="${OUTDIR}/bl1.bin" \
- --data css.cluster.cpu0="${OUTDIR}/iota-tiny-image-a5ds.wic@0x80000000" \
+ --data css.cluster.cpu0="${OUTDIR}/${YOCTO_IMAGE}-${MACHINE}.wic.nopt@0x80000000" \
$2
else
help
diff --git a/iot/scripts/platforms/a5ds/a5ds_fvp.py b/iot/scripts/platforms/corstone500/corstone500_fvp.py
index 78430c4..0e95fa9 100644
--- a/iot/scripts/platforms/a5ds/a5ds_fvp.py
+++ b/iot/scripts/platforms/corstone500/corstone500_fvp.py
@@ -2,7 +2,7 @@
# Python 2.7 is <required> for fm.debug
__copyright__ = """
-Copyright (c) 2019, Arm Limited and Contributors. All rights reserved.
+Copyright (c) 2019-2020, Arm Limited and Contributors. All rights reserved.
SPDX-License-Identifier: BSD-3-Clause
"""
@@ -13,16 +13,17 @@ a5ds_dir = os.path.dirname(os.path.realpath(__file__))
sys.path.append(os.path.join((a5ds_dir),'..','..', 'test'))
from fvp_wrapper import FVPWrapper, TelnetWatcher
-""" a5ds_fvp.py
-This file contains the a5ds FVP subclass of the generic FVP wrapper class.
+""" corstone500_fvp.py
+This file contains the Corstone-500 FVP subclass of the generic FVP wrapper class.
Upon instantiation, telnet watchers are created for each UART exposed by the
FVP, and - using the provided test specification - watchers are set up with their
respective stop and verification conditions.
+CA5DS has been rebranded to Corstone-500.
"""
"""a5dsDefaultConfig
-default a5ds configuration parameters.
+default Corstone-500 configuration parameters.
Note that these are fully platform dependant, and are only specified in the
following map to provide a clear overview of what the configuration constants
of this script are.
@@ -45,14 +46,14 @@ a5dsDefaultConfig = {
"host_telnet_port0" : 5000,
# =============== Test parameters ==============
- "linux_login_prompt" : "a5ds login:",
+ "linux_login_prompt" : "corstone500 login:",
"linux_user" : "root",
- "linux_shstring" : "root@a5ds:~# "
+ "linux_shstring" : "root@corstone500:~# "
}
""" a5dsDefaultTestspec
-Test-specification parameters for a5ds.
+Test-specification parameters for Corstone-500.
Note that this is fully platform-dependant, and only used during the
initialization of a5dsFVP.
"""
@@ -69,7 +70,7 @@ class A5dsFVP(FVPWrapper):
FVPWrapper.__init__(
self,
fvp_path=fvp_path,
- fvp_name="A5ds",
+ fvp_name="corstone500",
usermode=usermode,
work_dir=a5ds_dir,
fvp_timeout=fvp_timeout,
@@ -113,7 +114,7 @@ class A5dsFVP(FVPWrapper):
def getModelData(self):
# Assign images to FVP flashloaders
fvp_data = {}
- fvp_data[self.config['host_cpu0']] = os.path.join(self.image_dir, "iota-tiny-image-a5ds.wic" + "@" + self.config['address1'])
+ fvp_data[self.config['host_cpu0']] = os.path.join(self.image_dir, "arm-reference-image-corstone500.wic.nopt" + "@" + self.config['address1'])
print(fvp_data)
return fvp_data
diff --git a/iot/scripts/platforms/a5ds/a5ds_testrunner.py b/iot/scripts/platforms/corstone500/corstone500_testrunner.py
index d728ebc..79eb2c2 100644
--- a/iot/scripts/platforms/a5ds/a5ds_testrunner.py
+++ b/iot/scripts/platforms/corstone500/corstone500_testrunner.py
@@ -1,7 +1,7 @@
#!/usr/bin/env python2.7
__copyright__ = """
-Copyright (c) 2019, Arm Limited and Contributors. All rights reserved.
+Copyright (c) 2019-2020, Arm Limited and Contributors. All rights reserved.
SPDX-License-Identifier: BSD-3-Clause
"""
@@ -10,7 +10,7 @@ import sys
import os
sys.path.append(os.path.join((os.path.dirname(os.path.realpath(__file__))),'..','..','test'))
from testrunner import TestRunner
-from a5ds_fvp import A5dsFVP
+from corstone500_fvp import A5dsFVP
class A5dsTestRunner(TestRunner):
def __init__(self):
@@ -19,11 +19,11 @@ class A5dsTestRunner(TestRunner):
)
def setSpecializationArguments(self):
# a5ds_fvp requires an image_dir argument for its constructor
# to be able to locate various binaries. Add this as a command-line
# argument
self.parser.add_argument("--image_dir", type=str,
- help="Directory containing the a5ds images")
+ help="Directory containing the Corstone-500 images")
def parseSpecializationArguments(self, args):
def tryParseStringArg(arg, argstring):
@@ -48,8 +48,8 @@ class A5dsTestRunner(TestRunner):
'commands' : [
('w', "uname -srmn"),
],
- 'host_ver_strs' : ["Linux a5ds 5.2.0 armv7l"],
- 'host_stop_str' : "Linux a5ds 5.2.0 armv7l"
+ 'host_ver_strs' : ["Linux corstone500 5.3.18-yocto-standard armv7l"],
+ 'host_stop_str' : "Linux corstone500 5.3.18-yocto-standard armv7l"
})
if __name__ == "__main__":
@@ -19,11 +19,11 @@ class A5dsTestRunner(TestRunner):
)
def setSpecializationArguments(self):
- # a5ds_fvp requires an image_dir argument for its constructor
+ # corstone500_fvp requires an image_dir argument for its constructor
# to be able to locate various binaries. Add this as a command-line
# argument